@@ -5,9 +5,6 @@ TODO: rivedere esempi documentazione
 """
 __docformat__="numpy"
 
-from curses import use_env
-from email import header
-from ntpath import join
 import numpy as np
 from matplotlib import pyplot as plt
 from scipy.optimize import curve_fit
@@ -17,8 +14,6 @@ import pandas as pd
 from pint import UnitRegistry
 import re
 
-from sympy import true 
-
 def _tex_escape(text):
     """
         :param text: a plain text message
@@ -309,7 +304,7 @@ def fit(excel_name,file_result,f_fit,popt_names_latex,variabile_x,variabile_y,si
     #fit
 
     #fit iniziale
-    popt, pcov = curve_fit(f_fit,t,y,sigma=dy,absolute_sigma=true)
+    popt, pcov = curve_fit(f_fit,t,y,sigma=dy,absolute_sigma=True)
     #sigma efficace
     if dx:
         sigma_eff=np.sqrt(np.power(dy,2)+np.power(_deriva(f_fit, t, popt)*dx,2)) #potrebbe non funzionare
@@ -320,7 +315,7 @@ def fit(excel_name,file_result,f_fit,popt_names_latex,variabile_x,variabile_y,si
     #fit iterato
     for i in range(numero_iterazioni):
         sigma_eff=np.sqrt(np.power(dy,2)+np.power(_deriva(f_fit, t, popt)*dx,2)) #potrebbe non funzionare
-        popt, pcov = curve_fit(f_fit,t,y,sigma=sigma_eff,absolute_sigma=true)
+        popt, pcov = curve_fit(f_fit,t,y,sigma=sigma_eff,absolute_sigma=True)
 
     #ODR
     if use_ODR:
